pg-schema
Safe HaskellNone
LanguageGHC2021

PgSchema.Schema.Catalog

Description

Internal module: a type-level description of pg_catalog tables in PostgreSQL (the system catalogs), as required by pg-schema for code generation and queries.

Application code should not need this module: use your generated schema module and the supported public entry points (e.g. PgSchema.Generation and PgSchema.DML).

It remains in the package export list because of technical constraints (visibility of types and instances for other components and tests). Do not treat it as a stable public API, and avoid importing it directly unless you are maintaining custom codegen or library extensions.

Documentation

data PgCatalog Source #

Instances

Instances details
CSchema PgCatalog Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TTabs PgCatalog 
Instance details

Defined in PgSchema.Schema.Catalog

type TTabs PgCatalog = '[PGC "pg_attribute", PGC "pg_class", PGC "pg_constraint", PGC "pg_enum", PGC "pg_namespace", PGC "pg_type"]
type TTypes PgCatalog 
Instance details

Defined in PgSchema.Schema.Catalog

type TTypes PgCatalog = '[PGC "oid", PGC "int2", PGC "int2[]", PGC "float4", PGC "bool", PGC "name", PGC "char"]
(ToStar (TDBFieldInfoPgCatalog t f), ToStar t, ToStar f) => CDBFieldInfo PgCatalog t f Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TDBFieldInfo PgCatalog t f 
Instance details

Defined in PgSchema.Schema.Catalog

CRelDef PgCatalog (PGC "attribute__class") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TRelDef PgCatalog (PGC "attribute__class") 
Instance details

Defined in PgSchema.Schema.Catalog

type TRelDef PgCatalog (PGC "attribute__class") = 'RelDef (PGC "pg_attribute") (PGC "pg_class") '['("attrelid", "oid")]
CRelDef PgCatalog (PGC "attribute__type") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TRelDef PgCatalog (PGC "attribute__type") 
Instance details

Defined in PgSchema.Schema.Catalog

type TRelDef PgCatalog (PGC "attribute__type") = 'RelDef (PGC "pg_attribute") (PGC "pg_type") '['("atttypid", "oid")]
CRelDef PgCatalog (PGC "class__namespace") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TRelDef PgCatalog (PGC "class__namespace") 
Instance details

Defined in PgSchema.Schema.Catalog

type TRelDef PgCatalog (PGC "class__namespace") = 'RelDef (PGC "pg_class") (PGC "pg_namespace") '['("relnamespace", "oid")]
CRelDef PgCatalog (PGC "constraint__class") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TRelDef PgCatalog (PGC "constraint__class") 
Instance details

Defined in PgSchema.Schema.Catalog

type TRelDef PgCatalog (PGC "constraint__class") = 'RelDef (PGC "pg_constraint") (PGC "pg_class") '['("conrelid", "oid")]
CRelDef PgCatalog (PGC "constraint__fclass") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TRelDef PgCatalog (PGC "constraint__fclass") 
Instance details

Defined in PgSchema.Schema.Catalog

type TRelDef PgCatalog (PGC "constraint__fclass") = 'RelDef (PGC "pg_constraint") (PGC "pg_class") '['("confrelid", "oid")]
CRelDef PgCatalog (PGC "constraint__namespace") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TRelDef PgCatalog (PGC "constraint__namespace") 
Instance details

Defined in PgSchema.Schema.Catalog

type TRelDef PgCatalog (PGC "constraint__namespace") = 'RelDef (PGC "pg_constraint") (PGC "pg_namespace") '['("connamespace", "oid")]
CRelDef PgCatalog (PGC "enum__type") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TRelDef PgCatalog (PGC "enum__type") 
Instance details

Defined in PgSchema.Schema.Catalog

type TRelDef PgCatalog (PGC "enum__type") = 'RelDef (PGC "pg_enum") (PGC "pg_type") '['("enumtypid", "oid")]
CRelDef PgCatalog (PGC "type__namespace") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TRelDef PgCatalog (PGC "type__namespace") 
Instance details

Defined in PgSchema.Schema.Catalog

type TRelDef PgCatalog (PGC "type__namespace") = 'RelDef (PGC "pg_type") (PGC "pg_namespace") '['("typnamespace", "oid")]
CTabDef PgCatalog (PGC "pg_attribute") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TTabDef PgCatalog (PGC "pg_attribute") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTabDef PgCatalog (PGC "pg_attribute") = 'TabDef '["oid", "attrelid", "attname", "atttypid", "attnum", "attnotnull", "atthasdef"] '["oid"] '['["attrelid", "attname"], '["attrelid", "attnum"]]
CTabDef PgCatalog (PGC "pg_class") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TTabDef PgCatalog (PGC "pg_class") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTabDef PgCatalog (PGC "pg_class") = 'TabDef '["oid", "relnamespace", "relname", "relkind"] '["oid"] '['["relnamespace", "relname"]]
CTabDef PgCatalog (PGC "pg_constraint") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TTabDef PgCatalog (PGC "pg_constraint") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTabDef PgCatalog (PGC "pg_constraint") = 'TabDef '["oid", "connamespace", "conname", "contype", "conrelid", "confrelid", "conkey", "confkey", "confupdtypeid", "confdeltypeid"] '["oid"] '['["connamespace", "conname"]]
CTabDef PgCatalog (PGC "pg_enum") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TTabDef PgCatalog (PGC "pg_enum") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTabDef PgCatalog (PGC "pg_enum") = 'TabDef '["oid", "enumtypid", "enumlabel", "enumsortorder"] '["oid"] '['["enumtypid", "enumlabel"], '["enumtypid", "enumsortorder"]]
CTabDef PgCatalog (PGC "pg_namespace") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TTabDef PgCatalog (PGC "pg_namespace") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTabDef PgCatalog (PGC "pg_namespace") = 'TabDef '["oid", "nspname"] '["oid"] '['["nspname"]]
CTabDef PgCatalog (PGC "pg_type") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TTabDef PgCatalog (PGC "pg_type") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTabDef PgCatalog (PGC "pg_type") = 'TabDef '["oid", "typnamespace", "typname", "typcategory", "typelem"] '["oid"] '['["typnamespace", "typname"]]
CTabRels PgCatalog (PGC "pg_attribute") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TFrom PgCatalog (PGC "pg_attribute") 
Instance details

Defined in PgSchema.Schema.Catalog

type TFrom PgCatalog (PGC "pg_attribute") = '[PGC "attribute__class", PGC "attribute__type"]
type TTo PgCatalog (PGC "pg_attribute") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTo PgCatalog (PGC "pg_attribute") = '[] :: [NameNSK]
CTabRels PgCatalog (PGC "pg_class") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TFrom PgCatalog (PGC "pg_class") 
Instance details

Defined in PgSchema.Schema.Catalog

type TFrom PgCatalog (PGC "pg_class") = '[PGC "class__namespace"]
type TTo PgCatalog (PGC "pg_class") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTo PgCatalog (PGC "pg_class") = '[PGC "attribute__class", PGC "constraint__class", PGC "constraint__fclass"]
CTabRels PgCatalog (PGC "pg_constraint") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TFrom PgCatalog (PGC "pg_constraint") 
Instance details

Defined in PgSchema.Schema.Catalog

type TFrom PgCatalog (PGC "pg_constraint") = '[PGC "constraint__class", PGC "constraint__fclass", PGC "constraint__namespace"]
type TTo PgCatalog (PGC "pg_constraint") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTo PgCatalog (PGC "pg_constraint") = '[] :: [NameNSK]
CTabRels PgCatalog (PGC "pg_enum") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TFrom PgCatalog (PGC "pg_enum") 
Instance details

Defined in PgSchema.Schema.Catalog

type TFrom PgCatalog (PGC "pg_enum") = '[PGC "enum__type"]
type TTo PgCatalog (PGC "pg_enum") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTo PgCatalog (PGC "pg_enum") = '[] :: [NameNSK]
CTabRels PgCatalog (PGC "pg_namespace") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TFrom PgCatalog (PGC "pg_namespace") 
Instance details

Defined in PgSchema.Schema.Catalog

type TFrom PgCatalog (PGC "pg_namespace") = '[] :: [NameNSK]
type TTo PgCatalog (PGC "pg_namespace") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTo PgCatalog (PGC "pg_namespace") = '[PGC "type__namespace", PGC "class__namespace", PGC "constraint__namespace"]
CTabRels PgCatalog (PGC "pg_type") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TFrom PgCatalog (PGC "pg_type") 
Instance details

Defined in PgSchema.Schema.Catalog

type TFrom PgCatalog (PGC "pg_type") = '[PGC "type__namespace"]
type TTo PgCatalog (PGC "pg_type") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTo PgCatalog (PGC "pg_type") = '[PGC "enum__type", PGC "attribute__type"]
CTypDef PgCatalog (PGC "bool") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TTypDef PgCatalog (PGC "bool") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTypDef PgCatalog (PGC "bool")
CTypDef PgCatalog (PGC "char") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TTypDef PgCatalog (PGC "char") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTypDef PgCatalog (PGC "char")
CTypDef PgCatalog (PGC "float4") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TTypDef PgCatalog (PGC "float4") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTypDef PgCatalog (PGC "float4")
CTypDef PgCatalog (PGC "int2") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TTypDef PgCatalog (PGC "int2") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTypDef PgCatalog (PGC "int2")
CTypDef PgCatalog (PGC "int2[]") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TTypDef PgCatalog (PGC "int2[]") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTypDef PgCatalog (PGC "int2[]") = 'TypDef "A" ('Just (PGC "int2")) ('[] :: [Symbol])
CTypDef PgCatalog (PGC "name") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TTypDef PgCatalog (PGC "name") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTypDef PgCatalog (PGC "name")
CTypDef PgCatalog (PGC "oid") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

Associated Types

type TTypDef PgCatalog (PGC "oid") 
Instance details

Defined in PgSchema.Schema.Catalog

type TTypDef PgCatalog (PGC "oid")
type TTabs PgCatalog Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTabs PgCatalog = '[PGC "pg_attribute", PGC "pg_class", PGC "pg_constraint", PGC "pg_enum", PGC "pg_namespace", PGC "pg_type"]
type TTypes PgCatalog Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTypes PgCatalog = '[PGC "oid", PGC "int2", PGC "int2[]", PGC "float4", PGC "bool", PGC "name", PGC "char"]
type TDBFieldInfo PgCatalog t f Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TFrom PgCatalog (PGC "pg_attribute") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TFrom PgCatalog (PGC "pg_attribute") = '[PGC "attribute__class", PGC "attribute__type"]
type TFrom PgCatalog (PGC "pg_class") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TFrom PgCatalog (PGC "pg_class") = '[PGC "class__namespace"]
type TFrom PgCatalog (PGC "pg_constraint") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TFrom PgCatalog (PGC "pg_constraint") = '[PGC "constraint__class", PGC "constraint__fclass", PGC "constraint__namespace"]
type TFrom PgCatalog (PGC "pg_enum") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TFrom PgCatalog (PGC "pg_enum") = '[PGC "enum__type"]
type TFrom PgCatalog (PGC "pg_namespace") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TFrom PgCatalog (PGC "pg_namespace") = '[] :: [NameNSK]
type TFrom PgCatalog (PGC "pg_type") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TFrom PgCatalog (PGC "pg_type") = '[PGC "type__namespace"]
type TRelDef PgCatalog (PGC "attribute__class") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TRelDef PgCatalog (PGC "attribute__class") = 'RelDef (PGC "pg_attribute") (PGC "pg_class") '['("attrelid", "oid")]
type TRelDef PgCatalog (PGC "attribute__type") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TRelDef PgCatalog (PGC "attribute__type") = 'RelDef (PGC "pg_attribute") (PGC "pg_type") '['("atttypid", "oid")]
type TRelDef PgCatalog (PGC "class__namespace") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TRelDef PgCatalog (PGC "class__namespace") = 'RelDef (PGC "pg_class") (PGC "pg_namespace") '['("relnamespace", "oid")]
type TRelDef PgCatalog (PGC "constraint__class") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TRelDef PgCatalog (PGC "constraint__class") = 'RelDef (PGC "pg_constraint") (PGC "pg_class") '['("conrelid", "oid")]
type TRelDef PgCatalog (PGC "constraint__fclass") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TRelDef PgCatalog (PGC "constraint__fclass") = 'RelDef (PGC "pg_constraint") (PGC "pg_class") '['("confrelid", "oid")]
type TRelDef PgCatalog (PGC "constraint__namespace") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TRelDef PgCatalog (PGC "constraint__namespace") = 'RelDef (PGC "pg_constraint") (PGC "pg_namespace") '['("connamespace", "oid")]
type TRelDef PgCatalog (PGC "enum__type") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TRelDef PgCatalog (PGC "enum__type") = 'RelDef (PGC "pg_enum") (PGC "pg_type") '['("enumtypid", "oid")]
type TRelDef PgCatalog (PGC "type__namespace") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TRelDef PgCatalog (PGC "type__namespace") = 'RelDef (PGC "pg_type") (PGC "pg_namespace") '['("typnamespace", "oid")]
type TTabDef PgCatalog (PGC "pg_attribute") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTabDef PgCatalog (PGC "pg_attribute") = 'TabDef '["oid", "attrelid", "attname", "atttypid", "attnum", "attnotnull", "atthasdef"] '["oid"] '['["attrelid", "attname"], '["attrelid", "attnum"]]
type TTabDef PgCatalog (PGC "pg_class") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTabDef PgCatalog (PGC "pg_class") = 'TabDef '["oid", "relnamespace", "relname", "relkind"] '["oid"] '['["relnamespace", "relname"]]
type TTabDef PgCatalog (PGC "pg_constraint") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTabDef PgCatalog (PGC "pg_constraint") = 'TabDef '["oid", "connamespace", "conname", "contype", "conrelid", "confrelid", "conkey", "confkey", "confupdtypeid", "confdeltypeid"] '["oid"] '['["connamespace", "conname"]]
type TTabDef PgCatalog (PGC "pg_enum") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTabDef PgCatalog (PGC "pg_enum") = 'TabDef '["oid", "enumtypid", "enumlabel", "enumsortorder"] '["oid"] '['["enumtypid", "enumlabel"], '["enumtypid", "enumsortorder"]]
type TTabDef PgCatalog (PGC "pg_namespace") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTabDef PgCatalog (PGC "pg_namespace") = 'TabDef '["oid", "nspname"] '["oid"] '['["nspname"]]
type TTabDef PgCatalog (PGC "pg_type") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTabDef PgCatalog (PGC "pg_type") = 'TabDef '["oid", "typnamespace", "typname", "typcategory", "typelem"] '["oid"] '['["typnamespace", "typname"]]
type TTo PgCatalog (PGC "pg_attribute") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTo PgCatalog (PGC "pg_attribute") = '[] :: [NameNSK]
type TTo PgCatalog (PGC "pg_class") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTo PgCatalog (PGC "pg_class") = '[PGC "attribute__class", PGC "constraint__class", PGC "constraint__fclass"]
type TTo PgCatalog (PGC "pg_constraint") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTo PgCatalog (PGC "pg_constraint") = '[] :: [NameNSK]
type TTo PgCatalog (PGC "pg_enum") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTo PgCatalog (PGC "pg_enum") = '[] :: [NameNSK]
type TTo PgCatalog (PGC "pg_namespace") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTo PgCatalog (PGC "pg_namespace") = '[PGC "type__namespace", PGC "class__namespace", PGC "constraint__namespace"]
type TTo PgCatalog (PGC "pg_type") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTo PgCatalog (PGC "pg_type") = '[PGC "enum__type", PGC "attribute__type"]
type TTypDef PgCatalog (PGC "bool") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTypDef PgCatalog (PGC "bool")
type TTypDef PgCatalog (PGC "char") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTypDef PgCatalog (PGC "char")
type TTypDef PgCatalog (PGC "float4") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTypDef PgCatalog (PGC "float4")
type TTypDef PgCatalog (PGC "int2") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTypDef PgCatalog (PGC "int2")
type TTypDef PgCatalog (PGC "int2[]") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTypDef PgCatalog (PGC "int2[]") = 'TypDef "A" ('Just (PGC "int2")) ('[] :: [Symbol])
type TTypDef PgCatalog (PGC "name") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTypDef PgCatalog (PGC "name")
type TTypDef PgCatalog (PGC "oid") Source # 
Instance details

Defined in PgSchema.Schema.Catalog

type TTypDef PgCatalog (PGC "oid")

type PGC (name :: Symbol) = "pg_catalog" ->> name Source #

type family TDBFieldInfoPgCatalog (t :: NameNSK) (f :: Symbol) :: RecFieldK NameNSK where ... Source #

Equations

TDBFieldInfoPgCatalog (PGC "pg_attribute") "oid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_class") "oid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_constraint") "oid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_enum") "oid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_namespace") "oid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_type") "oid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_attribute") "attrelid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_attribute") "attname" = 'RFPlain ('FldDef (PGC "name") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_attribute") "atttypid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_attribute") "attnum" = 'RFPlain ('FldDef (PGC "int2") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_attribute") "attnotnull" = 'RFPlain ('FldDef (PGC "bool") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_attribute") "atthasdef" = 'RFPlain ('FldDef (PGC "bool") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_class") "relnamespace" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_class") "relname" = 'RFPlain ('FldDef (PGC "name") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_class") "relkind" = 'RFPlain ('FldDef (PGC "char") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_constraint") "connamespace" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_constraint") "conname" = 'RFPlain ('FldDef (PGC "name") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_constraint") "contype" = 'RFPlain ('FldDef (PGC "char") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_constraint") "conrelid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_constraint") "confrelid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_constraint") "confupdtypeid" = 'RFPlain ('FldDef (PGC "bool") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_constraint") "confdeltypeid" = 'RFPlain ('FldDef (PGC "bool") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_constraint") "conkey" = 'RFPlain ('FldDef (PGC "int2[]") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_constraint") "confkey" = 'RFPlain ('FldDef (PGC "int2[]") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_enum") "enumtypid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_enum") "enumlabel" = 'RFPlain ('FldDef (PGC "name") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_enum") "enumsortorder" = 'RFPlain ('FldDef (PGC "float4") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_namespace") "nspname" = 'RFPlain ('FldDef (PGC "name") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_type") "typnamespace" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_type") "typname" = 'RFPlain ('FldDef (PGC "name") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_type") "typcategory" = 'RFPlain ('FldDef (PGC "char") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_type") "typelem" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK 
TDBFieldInfoPgCatalog (PGC "pg_attribute") "attribute__class" = 'RFFromHere (PGC "pg_class") '['Ref "attrelid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] 
TDBFieldInfoPgCatalog (PGC "pg_attribute") "attribute__type" = 'RFFromHere (PGC "pg_type") '['Ref "atttypid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] 
TDBFieldInfoPgCatalog (PGC "pg_class") "attribute__class" = 'RFToHere (PGC "pg_attribute") '['Ref "attrelid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] 
TDBFieldInfoPgCatalog (PGC "pg_class") "class__namespace" = 'RFFromHere (PGC "pg_namespace") '['Ref "relnamespace" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] 
TDBFieldInfoPgCatalog (PGC "pg_class") "constraint__class" = 'RFToHere (PGC "pg_constraint") '['Ref "conrelid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] 
TDBFieldInfoPgCatalog (PGC "pg_class") "constraint__fclass" = 'RFToHere (PGC "pg_constraint") '['Ref "confrelid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] 
TDBFieldInfoPgCatalog (PGC "pg_constraint") "constraint__class" = 'RFFromHere (PGC "pg_class") '['Ref "conrelid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] 
TDBFieldInfoPgCatalog (PGC "pg_constraint") "constraint__fclass" = 'RFFromHere (PGC "pg_class") '['Ref "confrelid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] 
TDBFieldInfoPgCatalog (PGC "pg_constraint") "constraint__namespace" = 'RFFromHere (PGC "pg_namespace") '['Ref "connamespace" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] 
TDBFieldInfoPgCatalog (PGC "pg_enum") "enum__type" = 'RFFromHere (PGC "pg_type") '['Ref "enumtypid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] 
TDBFieldInfoPgCatalog (PGC "pg_type") "enum__type" = 'RFToHere (PGC "pg_enum") '['Ref "enumtypid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] 
TDBFieldInfoPgCatalog (PGC "pg_type") "type__namespace" = 'RFFromHere (PGC "pg_namespace") '['Ref "typnamespace" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] 
TDBFieldInfoPgCatalog (PGC "pg_namespace") "type__namespace" = 'RFToHere (PGC "pg_type") '['Ref "typnamespace" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] 
TDBFieldInfoPgCatalog (PGC "pg_namespace") "class__namespace" = 'RFToHere (PGC "pg_class") '['Ref "relnamespace" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] 
TDBFieldInfoPgCatalog (PGC "pg_namespace") "constraint__namespace" = 'RFToHere (PGC "pg_constraint") '['Ref "connamespace" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] 
TDBFieldInfoPgCatalog t f = TypeError (((('Text "In schema PgCatalog for table " ':<>: 'ShowType t) ':<>: 'Text " field ") ':<>: 'ShowType f) ':<>: 'Text " is not defined") :: RecFieldK NameNSK