| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
PgSchema.Schema.Catalog
Description
Internal module: a type-level description of pg_catalog tables in PostgreSQL
(the system catalogs), as required by pg-schema for code generation and queries.
Application code should not need this module: use your generated schema module and the supported public entry points (e.g. PgSchema.Generation and PgSchema.DML).
It remains in the package export list because of technical constraints (visibility of types and instances for other components and tests). Do not treat it as a stable public API, and avoid importing it directly unless you are maintaining custom codegen or library extensions.
Documentation
Instances
type family TDBFieldInfoPgCatalog (t :: NameNSK) (f :: Symbol) :: RecFieldK NameNSK where ... Source #
Equations
| TDBFieldInfoPgCatalog (PGC "pg_attribute") "oid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_class") "oid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_constraint") "oid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_enum") "oid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_namespace") "oid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_type") "oid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_attribute") "attrelid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_attribute") "attname" = 'RFPlain ('FldDef (PGC "name") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_attribute") "atttypid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_attribute") "attnum" = 'RFPlain ('FldDef (PGC "int2") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_attribute") "attnotnull" = 'RFPlain ('FldDef (PGC "bool") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_attribute") "atthasdef" = 'RFPlain ('FldDef (PGC "bool") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_class") "relnamespace" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_class") "relname" = 'RFPlain ('FldDef (PGC "name") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_class") "relkind" = 'RFPlain ('FldDef (PGC "char") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_constraint") "connamespace" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_constraint") "conname" = 'RFPlain ('FldDef (PGC "name") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_constraint") "contype" = 'RFPlain ('FldDef (PGC "char") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_constraint") "conrelid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_constraint") "confrelid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_constraint") "confupdtypeid" = 'RFPlain ('FldDef (PGC "bool") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_constraint") "confdeltypeid" = 'RFPlain ('FldDef (PGC "bool") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_constraint") "conkey" = 'RFPlain ('FldDef (PGC "int2[]") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_constraint") "confkey" = 'RFPlain ('FldDef (PGC "int2[]") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_enum") "enumtypid" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_enum") "enumlabel" = 'RFPlain ('FldDef (PGC "name") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_enum") "enumsortorder" = 'RFPlain ('FldDef (PGC "float4") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_namespace") "nspname" = 'RFPlain ('FldDef (PGC "name") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_type") "typnamespace" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_type") "typname" = 'RFPlain ('FldDef (PGC "name") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_type") "typcategory" = 'RFPlain ('FldDef (PGC "char") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_type") "typelem" = 'RFPlain ('FldDef (PGC "oid") 'False 'False) :: RecField' Symbol NameNSK | |
| TDBFieldInfoPgCatalog (PGC "pg_attribute") "attribute__class" = 'RFFromHere (PGC "pg_class") '['Ref "attrelid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] | |
| TDBFieldInfoPgCatalog (PGC "pg_attribute") "attribute__type" = 'RFFromHere (PGC "pg_type") '['Ref "atttypid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] | |
| TDBFieldInfoPgCatalog (PGC "pg_class") "attribute__class" = 'RFToHere (PGC "pg_attribute") '['Ref "attrelid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] | |
| TDBFieldInfoPgCatalog (PGC "pg_class") "class__namespace" = 'RFFromHere (PGC "pg_namespace") '['Ref "relnamespace" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] | |
| TDBFieldInfoPgCatalog (PGC "pg_class") "constraint__class" = 'RFToHere (PGC "pg_constraint") '['Ref "conrelid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] | |
| TDBFieldInfoPgCatalog (PGC "pg_class") "constraint__fclass" = 'RFToHere (PGC "pg_constraint") '['Ref "confrelid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] | |
| TDBFieldInfoPgCatalog (PGC "pg_constraint") "constraint__class" = 'RFFromHere (PGC "pg_class") '['Ref "conrelid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] | |
| TDBFieldInfoPgCatalog (PGC "pg_constraint") "constraint__fclass" = 'RFFromHere (PGC "pg_class") '['Ref "confrelid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] | |
| TDBFieldInfoPgCatalog (PGC "pg_constraint") "constraint__namespace" = 'RFFromHere (PGC "pg_namespace") '['Ref "connamespace" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] | |
| TDBFieldInfoPgCatalog (PGC "pg_enum") "enum__type" = 'RFFromHere (PGC "pg_type") '['Ref "enumtypid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] | |
| TDBFieldInfoPgCatalog (PGC "pg_type") "enum__type" = 'RFToHere (PGC "pg_enum") '['Ref "enumtypid" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] | |
| TDBFieldInfoPgCatalog (PGC "pg_type") "type__namespace" = 'RFFromHere (PGC "pg_namespace") '['Ref "typnamespace" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] | |
| TDBFieldInfoPgCatalog (PGC "pg_namespace") "type__namespace" = 'RFToHere (PGC "pg_type") '['Ref "typnamespace" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] | |
| TDBFieldInfoPgCatalog (PGC "pg_namespace") "class__namespace" = 'RFToHere (PGC "pg_class") '['Ref "relnamespace" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] | |
| TDBFieldInfoPgCatalog (PGC "pg_namespace") "constraint__namespace" = 'RFToHere (PGC "pg_constraint") '['Ref "connamespace" ('FldDef (PGC "oid") 'False 'False) "oid" ('FldDef (PGC "oid") 'False 'False)] | |
| TDBFieldInfoPgCatalog t f = TypeError (((('Text "In schema PgCatalog for table " ':<>: 'ShowType t) ':<>: 'Text " field ") ':<>: 'ShowType f) ':<>: 'Text " is not defined") :: RecFieldK NameNSK |